Class: Google::Apis::EventarcV1::Channel
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::Channel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
Represents a subscriber's intent to receive events from an event provider. Published events are delivered using the transport associated with the Channel resource. A channel is associated with exactly one event provider.
Instance Attribute Summary collapse
-
#activation_token ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#crypto_key_name ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Required.
-
#provider ⇒ String
The name of the event provider (e.g. Eventarc SaaS partner) associated with the channel.
-
#pubsub_topic ⇒ String
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Channel
constructor
A new instance of Channel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Channel
Returns a new instance of Channel.
271 272 273 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activation_token ⇒ String
Output only. The activation token for the channel. The token must be used by
the provider to register the channel for publishing.
Corresponds to the JSON property activationToken
207 208 209 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 207 def activation_token @activation_token end |
#create_time ⇒ String
Output only. The creation time.
Corresponds to the JSON property createTime
212 213 214 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 212 def create_time @create_time end |
#crypto_key_name ⇒ String
Optional. Resource name of a KMS crypto key (managed by the user) used to
encrypt/decrypt their event data. It must match the pattern projects/*/
locations/*/keyRings/*/cryptoKeys/*.
Corresponds to the JSON property cryptoKeyName
219 220 221 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 219 def crypto_key_name @crypto_key_name end |
#labels ⇒ Hash<String,String>
Optional. Resource labels.
Corresponds to the JSON property labels
224 225 226 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 224 def labels @labels end |
#name ⇒ String
Required. The resource name of the channel. Must be unique within the location
on the project and must be in projects/project/locations/location/
channels/channel_id`format.
Corresponds to the JSON propertyname`
231 232 233 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 231 def name @name end |
#provider ⇒ String
The name of the event provider (e.g. Eventarc SaaS partner) associated with
the channel. This provider will be granted permissions to publish events to
the channel. Format: projects/project/locations/location/providers/
provider_id`.
Corresponds to the JSON propertyprovider`
239 240 241 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 239 def provider @provider end |
#pubsub_topic ⇒ String
Output only. The name of the Pub/Sub topic created and managed by Eventarc
system as a transport for the event delivery. Format: projects/project/
topics/topic_id`.
Corresponds to the JSON propertypubsubTopic`
246 247 248 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 246 def pubsub_topic @pubsub_topic end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Whether or not this Channel satisfies the requirements of
physical zone separation
Corresponds to the JSON property satisfiesPzs
252 253 254 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 252 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. The state of a Channel.
Corresponds to the JSON property state
258 259 260 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 258 def state @state end |
#uid ⇒ String
Output only. Server assigned unique identifier for the channel. The value is a
UUID4 string and guaranteed to remain unchanged until the resource is deleted.
Corresponds to the JSON property uid
264 265 266 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 264 def uid @uid end |
#update_time ⇒ String
Output only. The last-modified time.
Corresponds to the JSON property updateTime
269 270 271 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 269 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 276 def update!(**args) @activation_token = args[:activation_token] if args.key?(:activation_token) @create_time = args[:create_time] if args.key?(:create_time) @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @provider = args[:provider] if args.key?(:provider) @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |