Class: Google::Apis::EventarcV1::ChannelConnection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb

Overview

A representation of the ChannelConnection resource. A ChannelConnection is a resource which event providers create during the activation process to establish a connection between the provider and the subscriber channel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelConnection

Returns a new instance of ChannelConnection.



337
338
339
# File 'lib/google/apis/eventarc_v1/classes.rb', line 337

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activation_tokenString

Input only. Activation token for the channel. The token will be used during the creation of ChannelConnection to bind the channel with the provider project. This field will not be stored in the provider resource. Corresponds to the JSON property activationToken

Returns:

  • (String)


302
303
304
# File 'lib/google/apis/eventarc_v1/classes.rb', line 302

def activation_token
  @activation_token
end

#channelString

Required. The name of the connected subscriber Channel. This is a weak reference to avoid cross project and cross accounts references. This must be in projects/project/location/location/channels/channel_id`format. Corresponds to the JSON propertychannel`

Returns:

  • (String)


309
310
311
# File 'lib/google/apis/eventarc_v1/classes.rb', line 309

def channel
  @channel
end

#create_timeString

Output only. The creation time. Corresponds to the JSON property createTime

Returns:

  • (String)


314
315
316
# File 'lib/google/apis/eventarc_v1/classes.rb', line 314

def create_time
  @create_time
end

#labelsHash<String,String>

Optional. Resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


319
320
321
# File 'lib/google/apis/eventarc_v1/classes.rb', line 319

def labels
  @labels
end

#nameString

Required. The name of the connection. Corresponds to the JSON property name

Returns:

  • (String)


324
325
326
# File 'lib/google/apis/eventarc_v1/classes.rb', line 324

def name
  @name
end

#uidString

Output only. Server assigned ID of the resource. The server guarantees uniqueness and immutability until deleted. Corresponds to the JSON property uid

Returns:

  • (String)


330
331
332
# File 'lib/google/apis/eventarc_v1/classes.rb', line 330

def uid
  @uid
end

#update_timeString

Output only. The last-modified time. Corresponds to the JSON property updateTime

Returns:

  • (String)


335
336
337
# File 'lib/google/apis/eventarc_v1/classes.rb', line 335

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



342
343
344
345
346
347
348
349
350
# File 'lib/google/apis/eventarc_v1/classes.rb', line 342

def update!(**args)
  @activation_token = args[:activation_token] if args.key?(:activation_token)
  @channel = args[:channel] if args.key?(:channel)
  @create_time = args[:create_time] if args.key?(:create_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end