Class: Google::Apis::EventarcV1::Enrollment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb

Overview

An enrollment represents a subscription for messages on a particular message bus. It defines a matching criteria for messages on the bus and the subscriber endpoint where matched messages should be delivered.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Enrollment

Returns a new instance of Enrollment.



529
530
531
# File 'lib/google/apis/eventarc_v1/classes.rb', line 529

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Resource annotations. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


468
469
470
# File 'lib/google/apis/eventarc_v1/classes.rb', line 468

def annotations
  @annotations
end

#cel_matchString

Required. A CEL expression identifying which messages this enrollment applies to. Corresponds to the JSON property celMatch

Returns:

  • (String)


474
475
476
# File 'lib/google/apis/eventarc_v1/classes.rb', line 474

def cel_match
  @cel_match
end

#create_timeString

Output only. The creation time. Corresponds to the JSON property createTime

Returns:

  • (String)


479
480
481
# File 'lib/google/apis/eventarc_v1/classes.rb', line 479

def create_time
  @create_time
end

#destinationString

Required. Destination is the Pipeline that the Enrollment is delivering to. It must point to the full resource name of a Pipeline. Format: "projects/ PROJECT_ID/locations/region/pipelines/PIPELINE_ID)" Corresponds to the JSON propertydestination`

Returns:

  • (String)


486
487
488
# File 'lib/google/apis/eventarc_v1/classes.rb', line 486

def destination
  @destination
end

#display_nameString

Optional. Resource display name. Corresponds to the JSON property displayName

Returns:

  • (String)


491
492
493
# File 'lib/google/apis/eventarc_v1/classes.rb', line 491

def display_name
  @display_name
end

#etagString

Output only. This checksum is computed by the server based on the value of other fields, and might be sent only on update and delete requests to ensure that the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


498
499
500
# File 'lib/google/apis/eventarc_v1/classes.rb', line 498

def etag
  @etag
end

#labelsHash<String,String>

Optional. Resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


503
504
505
# File 'lib/google/apis/eventarc_v1/classes.rb', line 503

def labels
  @labels
end

#message_busString

Required. Immutable. Resource name of the message bus identifying the source of the messages. It matches the form projects/project/locations/location/ messageBuses/messageBus. Corresponds to the JSON property messageBus

Returns:

  • (String)


510
511
512
# File 'lib/google/apis/eventarc_v1/classes.rb', line 510

def message_bus
  @message_bus
end

#nameString

Identifier. Resource name of the form projects/project/locations/location/ enrollments/enrollment Corresponds to the JSON property name

Returns:

  • (String)


516
517
518
# File 'lib/google/apis/eventarc_v1/classes.rb', line 516

def name
  @name
end

#uidString

Output only. Server assigned unique identifier for the channel. The value is a UUID4 string and guaranteed to remain unchanged until the resource is deleted. Corresponds to the JSON property uid

Returns:

  • (String)


522
523
524
# File 'lib/google/apis/eventarc_v1/classes.rb', line 522

def uid
  @uid
end

#update_timeString

Output only. The last-modified time. Corresponds to the JSON property updateTime

Returns:

  • (String)


527
528
529
# File 'lib/google/apis/eventarc_v1/classes.rb', line 527

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'lib/google/apis/eventarc_v1/classes.rb', line 534

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @cel_match = args[:cel_match] if args.key?(:cel_match)
  @create_time = args[:create_time] if args.key?(:create_time)
  @destination = args[:destination] if args.key?(:destination)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @message_bus = args[:message_bus] if args.key?(:message_bus)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end