Class: Google::Apis::EventarcV1::EventType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb

Overview

A representation of the event type resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EventType

Returns a new instance of EventType.



617
618
619
# File 'lib/google/apis/eventarc_v1/classes.rb', line 617

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Output only. Human friendly description of what the event type is about. For example "Bucket created in Cloud Storage". Corresponds to the JSON property description

Returns:

  • (String)


594
595
596
# File 'lib/google/apis/eventarc_v1/classes.rb', line 594

def description
  @description
end

#event_schema_uriString

Output only. URI for the event schema. For example "https://github.com/ googleapis/google-cloudevents/blob/master/proto/google/events/cloud/storage/v1/ events.proto" Corresponds to the JSON property eventSchemaUri

Returns:

  • (String)


601
602
603
# File 'lib/google/apis/eventarc_v1/classes.rb', line 601

def event_schema_uri
  @event_schema_uri
end

#filtering_attributesArray<Google::Apis::EventarcV1::FilteringAttribute>

Output only. Filtering attributes for the event type. Corresponds to the JSON property filteringAttributes



606
607
608
# File 'lib/google/apis/eventarc_v1/classes.rb', line 606

def filtering_attributes
  @filtering_attributes
end

#typeString

Output only. The full name of the event type (for example, "google.cloud. storage.object.v1.finalized"). In the form of provider-specific-prefix. resource.version.verb. Types MUST be versioned and event schemas are guaranteed to remain backward compatible within one version. Note that event type versions and API versions do not need to match. Corresponds to the JSON property type

Returns:

  • (String)


615
616
617
# File 'lib/google/apis/eventarc_v1/classes.rb', line 615

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



622
623
624
625
626
627
# File 'lib/google/apis/eventarc_v1/classes.rb', line 622

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @event_schema_uri = args[:event_schema_uri] if args.key?(:event_schema_uri)
  @filtering_attributes = args[:filtering_attributes] if args.key?(:filtering_attributes)
  @type = args[:type] if args.key?(:type)
end