Class: Google::Apis::EventarcV1::Gke

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb

Overview

Represents a GKE destination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Gke

Returns a new instance of Gke.



760
761
762
# File 'lib/google/apis/eventarc_v1/classes.rb', line 760

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusterString

Required. The name of the cluster the GKE service is running in. The cluster must be running in the same project as the trigger being created. Corresponds to the JSON property cluster

Returns:

  • (String)


734
735
736
# File 'lib/google/apis/eventarc_v1/classes.rb', line 734

def cluster
  @cluster
end

#locationString

Required. The name of the Google Compute Engine in which the cluster resides, which can either be compute zone (for example, us-central1-a) for the zonal clusters or region (for example, us-central1) for regional clusters. Corresponds to the JSON property location

Returns:

  • (String)


741
742
743
# File 'lib/google/apis/eventarc_v1/classes.rb', line 741

def location
  @location
end

#namespaceString

Required. The namespace the GKE service is running in. Corresponds to the JSON property namespace

Returns:

  • (String)


746
747
748
# File 'lib/google/apis/eventarc_v1/classes.rb', line 746

def namespace
  @namespace
end

#pathString

Optional. The relative path on the GKE service the events should be sent to. The value must conform to the definition of a URI path segment (section 3.3 of RFC2396). Examples: "/route", "route", "route/subroute". Corresponds to the JSON property path

Returns:

  • (String)


753
754
755
# File 'lib/google/apis/eventarc_v1/classes.rb', line 753

def path
  @path
end

#serviceString

Required. Name of the GKE service. Corresponds to the JSON property service

Returns:

  • (String)


758
759
760
# File 'lib/google/apis/eventarc_v1/classes.rb', line 758

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



765
766
767
768
769
770
771
# File 'lib/google/apis/eventarc_v1/classes.rb', line 765

def update!(**args)
  @cluster = args[:cluster] if args.key?(:cluster)
  @location = args[:location] if args.key?(:location)
  @namespace = args[:namespace] if args.key?(:namespace)
  @path = args[:path] if args.key?(:path)
  @service = args[:service] if args.key?(:service)
end