Class: Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOidcToken

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb

Overview

Represents a config used to authenticate with a Google OIDC token using a Google Cloud service account. Use this authentication method to invoke your Cloud Run and Cloud Functions destinations or HTTP endpoints that support Google OIDC.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOidcToken

Returns a new instance of GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOidcToken.



1073
1074
1075
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1073

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audienceString

Optional. Audience to be used to generate the OIDC Token. The audience claim identifies the recipient that the JWT is intended for. If unspecified, the destination URI will be used. Corresponds to the JSON property audience

Returns:

  • (String)


1061
1062
1063
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1061

def audience
  @audience
end

#service_accountString

Required. Service account email used to generate the OIDC Token. The principal who calls this API must have iam.serviceAccounts.actAs permission in the service account. See https://cloud.google.com/iam/docs/understanding-service- accounts for more information. Eventarc service agents must have roles/roles/ iam.serviceAccountTokenCreator role to allow the Pipeline to create OpenID tokens for authenticated requests. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


1071
1072
1073
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1071

def 
  @service_account
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1078
1079
1080
1081
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1078

def update!(**args)
  @audience = args[:audience] if args.key?(:audience)
  @service_account = args[:service_account] if args.key?(:service_account)
end