Class: Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineRetryPolicy
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineRetryPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
The retry policy configuration for the Pipeline. The pipeline exponentially backs off in case the destination is non responsive or returns a retryable error code. The default semantics are as follows: The backoff starts with a 5 second delay and doubles the delay after each failed attempt (10 seconds, 20 seconds, 40 seconds, etc.). The delay is capped at 60 seconds by default. Please note that if you set the min_retry_delay and max_retry_delay fields to the same value this will make the duration between retries constant.
Instance Attribute Summary collapse
-
#max_attempts ⇒ Fixnum
Optional.
-
#max_retry_delay ⇒ String
Optional.
-
#min_retry_delay ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudEventarcV1PipelineRetryPolicy
constructor
A new instance of GoogleCloudEventarcV1PipelineRetryPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudEventarcV1PipelineRetryPolicy
Returns a new instance of GoogleCloudEventarcV1PipelineRetryPolicy.
1412 1413 1414 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1412 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_attempts ⇒ Fixnum
Optional. The maximum number of delivery attempts for any message. The value
must be between 1 and 100. The default value for this field is 5.
Corresponds to the JSON property maxAttempts
1398 1399 1400 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1398 def max_attempts @max_attempts end |
#max_retry_delay ⇒ String
Optional. The maximum amount of seconds to wait between retry attempts. The
value must be between 1 and 600. The default value for this field is 60.
Corresponds to the JSON property maxRetryDelay
1404 1405 1406 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1404 def max_retry_delay @max_retry_delay end |
#min_retry_delay ⇒ String
Optional. The minimum amount of seconds to wait between retry attempts. The
value must be between 1 and 600. The default value for this field is 5.
Corresponds to the JSON property minRetryDelay
1410 1411 1412 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1410 def min_retry_delay @min_retry_delay end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1417 1418 1419 1420 1421 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1417 def update!(**args) @max_attempts = args[:max_attempts] if args.key?(:max_attempts) @max_retry_delay = args[:max_retry_delay] if args.key?(:max_retry_delay) @min_retry_delay = args[:min_retry_delay] if args.key?(:min_retry_delay) end |