Class: Google::Apis::EventarcV1::HttpEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::HttpEndpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
Represents a HTTP endpoint destination.
Instance Attribute Summary collapse
-
#uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpEndpoint
constructor
A new instance of HttpEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpEndpoint
Returns a new instance of HttpEndpoint.
1585 1586 1587 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1585 def initialize(**args) update!(**args) end |
Instance Attribute Details
#uri ⇒ String
Required. The URI of the HTTP endpoint. The value must be a RFC2396 URI string.
Examples: http://10.10.10.8:80/route, http://svc.us-central1.p.local:8080/
. Only HTTP and HTTPS protocols are supported. The host can be either a static
IP addressable from the VPC specified by the network config, or an internal
DNS hostname of the service resolvable via Cloud DNS.
Corresponds to the JSON property uri
1583 1584 1585 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1583 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1590 1591 1592 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1590 def update!(**args) @uri = args[:uri] if args.key?(:uri) end |