Class: Google::Apis::EventarcV1::ListChannelConnectionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb

Overview

The response message for the ListChannelConnections method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListChannelConnectionsResponse

Returns a new instance of ListChannelConnectionsResponse.



1615
1616
1617
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1615

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channel_connectionsArray<Google::Apis::EventarcV1::ChannelConnection>

The requested channel connections, up to the number specified in page_size. Corresponds to the JSON property channelConnections



1602
1603
1604
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1602

def channel_connections
  @channel_connections
end

#next_page_tokenString

A page token that can be sent to ListChannelConnections to request the next page. If this is empty, then there are no more pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1608
1609
1610
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1608

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unreachable resources, if any. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1613
1614
1615
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1613

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1620
1621
1622
1623
1624
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1620

def update!(**args)
  @channel_connections = args[:channel_connections] if args.key?(:channel_connections)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end