Class: Google::Apis::EventarcV1::ListChannelsResponse
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::ListChannelsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
The response message for the ListChannels method.
Instance Attribute Summary collapse
-
#channels ⇒ Array<Google::Apis::EventarcV1::Channel>
The requested channels, up to the number specified in
page_size. -
#next_page_token ⇒ String
A page token that can be sent to
ListChannelsto request the next page. -
#unreachable ⇒ Array<String>
Unreachable resources, if any.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListChannelsResponse
constructor
A new instance of ListChannelsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListChannelsResponse
Returns a new instance of ListChannelsResponse.
1647 1648 1649 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1647 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channels ⇒ Array<Google::Apis::EventarcV1::Channel>
The requested channels, up to the number specified in page_size.
Corresponds to the JSON property channels
1634 1635 1636 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1634 def channels @channels end |
#next_page_token ⇒ String
A page token that can be sent to ListChannels to request the next page. If
this is empty, then there are no more pages.
Corresponds to the JSON property nextPageToken
1640 1641 1642 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1640 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unreachable resources, if any.
Corresponds to the JSON property unreachable
1645 1646 1647 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1645 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1652 1653 1654 1655 1656 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1652 def update!(**args) @channels = args[:channels] if args.key?(:channels) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |