Class: Google::Apis::EventarcV1::Channel
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::Channel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
A representation of the Channel resource. A Channel is a resource on which event providers publish their events. The published events are delivered through the transport associated with the channel. Note that a channel is associated with exactly one event provider.
Instance Attribute Summary collapse
-
#activation_token ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#crypto_key_name ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Required.
-
#provider ⇒ String
The name of the event provider (e.g. Eventarc SaaS partner) associated with the channel.
-
#pubsub_topic ⇒ String
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Channel
constructor
A new instance of Channel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Channel
Returns a new instance of Channel.
272 273 274 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 272 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activation_token ⇒ String
Output only. The activation token for the channel. The token must be used by
the provider to register the channel for publishing.
Corresponds to the JSON property activationToken
208 209 210 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 208 def activation_token @activation_token end |
#create_time ⇒ String
Output only. The creation time.
Corresponds to the JSON property createTime
213 214 215 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 213 def create_time @create_time end |
#crypto_key_name ⇒ String
Optional. Resource name of a KMS crypto key (managed by the user) used to
encrypt/decrypt their event data. It must match the pattern projects/*/
locations/*/keyRings/*/cryptoKeys/*.
Corresponds to the JSON property cryptoKeyName
220 221 222 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 220 def crypto_key_name @crypto_key_name end |
#labels ⇒ Hash<String,String>
Optional. Resource labels.
Corresponds to the JSON property labels
225 226 227 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 225 def labels @labels end |
#name ⇒ String
Required. The resource name of the channel. Must be unique within the location
on the project and must be in projects/project/locations/location/
channels/channel_id`format.
Corresponds to the JSON propertyname`
232 233 234 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 232 def name @name end |
#provider ⇒ String
The name of the event provider (e.g. Eventarc SaaS partner) associated with
the channel. This provider will be granted permissions to publish events to
the channel. Format: projects/project/locations/location/providers/
provider_id`.
Corresponds to the JSON propertyprovider`
240 241 242 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 240 def provider @provider end |
#pubsub_topic ⇒ String
Output only. The name of the Pub/Sub topic created and managed by Eventarc
system as a transport for the event delivery. Format: projects/project/
topics/topic_id`.
Corresponds to the JSON propertypubsubTopic`
247 248 249 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 247 def pubsub_topic @pubsub_topic end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Whether or not this Channel satisfies the requirements of
physical zone separation
Corresponds to the JSON property satisfiesPzs
253 254 255 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 253 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. The state of a Channel.
Corresponds to the JSON property state
259 260 261 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 259 def state @state end |
#uid ⇒ String
Output only. Server assigned unique identifier for the channel. The value is a
UUID4 string and guaranteed to remain unchanged until the resource is deleted.
Corresponds to the JSON property uid
265 266 267 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 265 def uid @uid end |
#update_time ⇒ String
Output only. The last-modified time.
Corresponds to the JSON property updateTime
270 271 272 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 270 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 277 def update!(**args) @activation_token = args[:activation_token] if args.key?(:activation_token) @create_time = args[:create_time] if args.key?(:create_time) @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @provider = args[:provider] if args.key?(:provider) @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |