Class: Google::Apis::EventarcV1::ChannelConnection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb

Overview

A representation of the ChannelConnection resource. A ChannelConnection is a resource which event providers create during the activation process to establish a connection between the provider and the subscriber channel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelConnection

Returns a new instance of ChannelConnection.



338
339
340
# File 'lib/google/apis/eventarc_v1/classes.rb', line 338

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activation_tokenString

Input only. Activation token for the channel. The token will be used during the creation of ChannelConnection to bind the channel with the provider project. This field will not be stored in the provider resource. Corresponds to the JSON property activationToken

Returns:

  • (String)


303
304
305
# File 'lib/google/apis/eventarc_v1/classes.rb', line 303

def activation_token
  @activation_token
end

#channelString

Required. The name of the connected subscriber Channel. This is a weak reference to avoid cross project and cross accounts references. This must be in projects/project/location/location/channels/channel_id`format. Corresponds to the JSON propertychannel`

Returns:

  • (String)


310
311
312
# File 'lib/google/apis/eventarc_v1/classes.rb', line 310

def channel
  @channel
end

#create_timeString

Output only. The creation time. Corresponds to the JSON property createTime

Returns:

  • (String)


315
316
317
# File 'lib/google/apis/eventarc_v1/classes.rb', line 315

def create_time
  @create_time
end

#labelsHash<String,String>

Optional. Resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


320
321
322
# File 'lib/google/apis/eventarc_v1/classes.rb', line 320

def labels
  @labels
end

#nameString

Required. The name of the connection. Corresponds to the JSON property name

Returns:

  • (String)


325
326
327
# File 'lib/google/apis/eventarc_v1/classes.rb', line 325

def name
  @name
end

#uidString

Output only. Server assigned ID of the resource. The server guarantees uniqueness and immutability until deleted. Corresponds to the JSON property uid

Returns:

  • (String)


331
332
333
# File 'lib/google/apis/eventarc_v1/classes.rb', line 331

def uid
  @uid
end

#update_timeString

Output only. The last-modified time. Corresponds to the JSON property updateTime

Returns:

  • (String)


336
337
338
# File 'lib/google/apis/eventarc_v1/classes.rb', line 336

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



343
344
345
346
347
348
349
350
351
# File 'lib/google/apis/eventarc_v1/classes.rb', line 343

def update!(**args)
  @activation_token = args[:activation_token] if args.key?(:activation_token)
  @channel = args[:channel] if args.key?(:channel)
  @create_time = args[:create_time] if args.key?(:create_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end