Class: Google::Apis::EventarcV1::Enrollment
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::Enrollment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
An enrollment represents a subscription for messages on a particular message bus. It defines a matching criteria for messages on the bus and the subscriber endpoint where matched messages should be delivered.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#cel_match ⇒ String
Required.
-
#create_time ⇒ String
Output only.
-
#destination ⇒ String
Required.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#message_bus ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Enrollment
constructor
A new instance of Enrollment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Enrollment
Returns a new instance of Enrollment.
530 531 532 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 530 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Resource annotations.
Corresponds to the JSON property annotations
469 470 471 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 469 def annotations @annotations end |
#cel_match ⇒ String
Required. A CEL expression identifying which messages this enrollment applies
to.
Corresponds to the JSON property celMatch
475 476 477 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 475 def cel_match @cel_match end |
#create_time ⇒ String
Output only. The creation time.
Corresponds to the JSON property createTime
480 481 482 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 480 def create_time @create_time end |
#destination ⇒ String
Required. Destination is the Pipeline that the Enrollment is delivering to. It
must point to the full resource name of a Pipeline. Format: "projects/
PROJECT_ID/locations/region/pipelines/PIPELINE_ID)"
Corresponds to the JSON propertydestination`
487 488 489 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 487 def destination @destination end |
#display_name ⇒ String
Optional. Resource display name.
Corresponds to the JSON property displayName
492 493 494 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 492 def display_name @display_name end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and might be sent only on update and delete requests to ensure
that the client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
499 500 501 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 499 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Resource labels.
Corresponds to the JSON property labels
504 505 506 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 504 def labels @labels end |
#message_bus ⇒ String
Required. Immutable. Resource name of the message bus identifying the source
of the messages. It matches the form projects/project/locations/location/
messageBuses/messageBus.
Corresponds to the JSON property messageBus
511 512 513 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 511 def @message_bus end |
#name ⇒ String
Identifier. Resource name of the form projects/project/locations/location/
enrollments/enrollment
Corresponds to the JSON property name
517 518 519 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 517 def name @name end |
#uid ⇒ String
Output only. Server assigned unique identifier for the channel. The value is a
UUID4 string and guaranteed to remain unchanged until the resource is deleted.
Corresponds to the JSON property uid
523 524 525 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 523 def uid @uid end |
#update_time ⇒ String
Output only. The last-modified time.
Corresponds to the JSON property updateTime
528 529 530 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 528 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 535 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @cel_match = args[:cel_match] if args.key?(:cel_match) @create_time = args[:create_time] if args.key?(:create_time) @destination = args[:destination] if args.key?(:destination) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @message_bus = args[:message_bus] if args.key?(:message_bus) @name = args[:name] if args.key?(:name) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |