Class: Google::Apis::EventarcV1::Gke
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::Gke
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
Represents a GKE destination.
Instance Attribute Summary collapse
-
#cluster ⇒ String
Required.
-
#location ⇒ String
Required.
-
#namespace ⇒ String
Required.
-
#path ⇒ String
Optional.
-
#service ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Gke
constructor
A new instance of Gke.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Gke
Returns a new instance of Gke.
761 762 763 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 761 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster ⇒ String
Required. The name of the cluster the GKE service is running in. The cluster
must be running in the same project as the trigger being created.
Corresponds to the JSON property cluster
735 736 737 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 735 def cluster @cluster end |
#location ⇒ String
Required. The name of the Google Compute Engine in which the cluster resides,
which can either be compute zone (for example, us-central1-a) for the zonal
clusters or region (for example, us-central1) for regional clusters.
Corresponds to the JSON property location
742 743 744 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 742 def location @location end |
#namespace ⇒ String
Required. The namespace the GKE service is running in.
Corresponds to the JSON property namespace
747 748 749 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 747 def namespace @namespace end |
#path ⇒ String
Optional. The relative path on the GKE service the events should be sent to.
The value must conform to the definition of a URI path segment (section 3.3 of
RFC2396). Examples: "/route", "route", "route/subroute".
Corresponds to the JSON property path
754 755 756 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 754 def path @path end |
#service ⇒ String
Required. Name of the GKE service.
Corresponds to the JSON property service
759 760 761 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 759 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
766 767 768 769 770 771 772 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 766 def update!(**args) @cluster = args[:cluster] if args.key?(:cluster) @location = args[:location] if args.key?(:location) @namespace = args[:namespace] if args.key?(:namespace) @path = args[:path] if args.key?(:path) @service = args[:service] if args.key?(:service) end |