Class: Google::Apis::EventarcV1::GoogleApiSource
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::GoogleApiSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
Represents a subscription to first-party events for a MessageBus resource. A GoogleApiSource resource lets you configure the delivery of events from Google API sources to a designated bus.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#crypto_key_name ⇒ String
Optional.
-
#destination ⇒ String
Required.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#logging_config ⇒ Google::Apis::EventarcV1::LoggingConfig
The configuration for Platform Telemetry logging for Eventarc Advanced resources.
-
#name ⇒ String
Identifier.
-
#organization_subscription ⇒ Google::Apis::EventarcV1::OrganizationSubscription
Config to enabled subscribing to events from other projects in the org.
-
#project_subscriptions ⇒ Google::Apis::EventarcV1::ProjectSubscriptions
Config to enable subscribing to all events from a list of projects.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleApiSource
constructor
A new instance of GoogleApiSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleApiSource
Returns a new instance of GoogleApiSource.
855 856 857 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 855 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Resource annotations.
Corresponds to the JSON property annotations
783 784 785 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 783 def annotations @annotations end |
#create_time ⇒ String
Output only. The creation time.
Corresponds to the JSON property createTime
788 789 790 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 788 def create_time @create_time end |
#crypto_key_name ⇒ String
Optional. Resource name of a KMS crypto key (managed by the user) used to
encrypt/decrypt their event data. It must match the pattern projects/*/
locations/*/keyRings/*/cryptoKeys/*.
Corresponds to the JSON property cryptoKeyName
795 796 797 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 795 def crypto_key_name @crypto_key_name end |
#destination ⇒ String
Required. Destination is the message bus that the GoogleApiSource is
delivering to. It must be point to the full resource name of a MessageBus.
Format: "projects/PROJECT_ID/locations/region/messagesBuses/
MESSAGE_BUS_ID)
Corresponds to the JSON propertydestination`
803 804 805 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 803 def destination @destination end |
#display_name ⇒ String
Optional. Resource display name.
Corresponds to the JSON property displayName
808 809 810 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 808 def display_name @display_name end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and might be sent only on update and delete requests to ensure
that the client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
815 816 817 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 815 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Resource labels.
Corresponds to the JSON property labels
820 821 822 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 820 def labels @labels end |
#logging_config ⇒ Google::Apis::EventarcV1::LoggingConfig
The configuration for Platform Telemetry logging for Eventarc Advanced
resources.
Corresponds to the JSON property loggingConfig
826 827 828 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 826 def logging_config @logging_config end |
#name ⇒ String
Identifier. Resource name of the form projects/project/locations/location/
googleApiSources/google_api_source
Corresponds to the JSON property name
832 833 834 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 832 def name @name end |
#organization_subscription ⇒ Google::Apis::EventarcV1::OrganizationSubscription
Config to enabled subscribing to events from other projects in the org.
Corresponds to the JSON property organizationSubscription
837 838 839 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 837 def organization_subscription @organization_subscription end |
#project_subscriptions ⇒ Google::Apis::EventarcV1::ProjectSubscriptions
Config to enable subscribing to all events from a list of projects.
Corresponds to the JSON property projectSubscriptions
842 843 844 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 842 def project_subscriptions @project_subscriptions end |
#uid ⇒ String
Output only. Server assigned unique identifier for the channel. The value is a
UUID4 string and guaranteed to remain unchanged until the resource is deleted.
Corresponds to the JSON property uid
848 849 850 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 848 def uid @uid end |
#update_time ⇒ String
Output only. The last-modified time.
Corresponds to the JSON property updateTime
853 854 855 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 853 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 860 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name) @destination = args[:destination] if args.key?(:destination) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @logging_config = args[:logging_config] if args.key?(:logging_config) @name = args[:name] if args.key?(:name) @organization_subscription = args[:organization_subscription] if args.key?(:organization_subscription) @project_subscriptions = args[:project_subscriptions] if args.key?(:project_subscriptions) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |