Class: Google::Apis::EventarcV1::GoogleApiSource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb

Overview

A GoogleApiSource represents a subscription of 1P events from a MessageBus.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleApiSource

Returns a new instance of GoogleApiSource.



854
855
856
# File 'lib/google/apis/eventarc_v1/classes.rb', line 854

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Resource annotations. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


782
783
784
# File 'lib/google/apis/eventarc_v1/classes.rb', line 782

def annotations
  @annotations
end

#create_timeString

Output only. The creation time. Corresponds to the JSON property createTime

Returns:

  • (String)


787
788
789
# File 'lib/google/apis/eventarc_v1/classes.rb', line 787

def create_time
  @create_time
end

#crypto_key_nameString

Optional. Resource name of a KMS crypto key (managed by the user) used to encrypt/decrypt their event data. It must match the pattern projects/*/ locations/*/keyRings/*/cryptoKeys/*. Corresponds to the JSON property cryptoKeyName

Returns:

  • (String)


794
795
796
# File 'lib/google/apis/eventarc_v1/classes.rb', line 794

def crypto_key_name
  @crypto_key_name
end

#destinationString

Required. Destination is the message bus that the GoogleApiSource is delivering to. It must be point to the full resource name of a MessageBus. Format: "projects/PROJECT_ID/locations/region/messagesBuses/ MESSAGE_BUS_ID) Corresponds to the JSON propertydestination`

Returns:

  • (String)


802
803
804
# File 'lib/google/apis/eventarc_v1/classes.rb', line 802

def destination
  @destination
end

#display_nameString

Optional. Resource display name. Corresponds to the JSON property displayName

Returns:

  • (String)


807
808
809
# File 'lib/google/apis/eventarc_v1/classes.rb', line 807

def display_name
  @display_name
end

#etagString

Output only. This checksum is computed by the server based on the value of other fields, and might be sent only on update and delete requests to ensure that the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


814
815
816
# File 'lib/google/apis/eventarc_v1/classes.rb', line 814

def etag
  @etag
end

#labelsHash<String,String>

Optional. Resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


819
820
821
# File 'lib/google/apis/eventarc_v1/classes.rb', line 819

def labels
  @labels
end

#logging_configGoogle::Apis::EventarcV1::LoggingConfig

The configuration for Platform Telemetry logging for Eventarc Advanced resources. Corresponds to the JSON property loggingConfig



825
826
827
# File 'lib/google/apis/eventarc_v1/classes.rb', line 825

def logging_config
  @logging_config
end

#nameString

Identifier. Resource name of the form projects/project/locations/location/ googleApiSources/google_api_source Corresponds to the JSON property name

Returns:

  • (String)


831
832
833
# File 'lib/google/apis/eventarc_v1/classes.rb', line 831

def name
  @name
end

#organization_subscriptionGoogle::Apis::EventarcV1::OrganizationSubscription

Config to enabled subscribing to events from other projects in the org. Corresponds to the JSON property organizationSubscription



836
837
838
# File 'lib/google/apis/eventarc_v1/classes.rb', line 836

def organization_subscription
  @organization_subscription
end

#project_subscriptionsGoogle::Apis::EventarcV1::ProjectSubscriptions

Config to enable subscribing to all events from a list of projects. Corresponds to the JSON property projectSubscriptions



841
842
843
# File 'lib/google/apis/eventarc_v1/classes.rb', line 841

def project_subscriptions
  @project_subscriptions
end

#uidString

Output only. Server assigned unique identifier for the channel. The value is a UUID4 string and guaranteed to remain unchanged until the resource is deleted. Corresponds to the JSON property uid

Returns:

  • (String)


847
848
849
# File 'lib/google/apis/eventarc_v1/classes.rb', line 847

def uid
  @uid
end

#update_timeString

Output only. The last-modified time. Corresponds to the JSON property updateTime

Returns:

  • (String)


852
853
854
# File 'lib/google/apis/eventarc_v1/classes.rb', line 852

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
# File 'lib/google/apis/eventarc_v1/classes.rb', line 859

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @create_time = args[:create_time] if args.key?(:create_time)
  @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name)
  @destination = args[:destination] if args.key?(:destination)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @logging_config = args[:logging_config] if args.key?(:logging_config)
  @name = args[:name] if args.key?(:name)
  @organization_subscription = args[:organization_subscription] if args.key?(:organization_subscription)
  @project_subscriptions = args[:project_subscriptions] if args.key?(:project_subscriptions)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end