Class: Google::Apis::EventarcV1::GoogleChannelConfig
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::GoogleChannelConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
Can be used to customize security settings for Eventarc first-party triggers in a specific region. Once the GoogleChannelConfig resource is configured, first-party event data is protected using the specified customer-managed encryption key instead of a Google-managed encryption key.
Instance Attribute Summary collapse
-
#crypto_key_name ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChannelConfig
constructor
A new instance of GoogleChannelConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChannelConfig
Returns a new instance of GoogleChannelConfig.
909 910 911 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 909 def initialize(**args) update!(**args) end |
Instance Attribute Details
#crypto_key_name ⇒ String
Optional. Resource name of a KMS crypto key (managed by the user) used to
encrypt/decrypt their event data. It must match the pattern projects/*/
locations/*/keyRings/*/cryptoKeys/*.
Corresponds to the JSON property cryptoKeyName
889 890 891 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 889 def crypto_key_name @crypto_key_name end |
#labels ⇒ Hash<String,String>
Optional. Resource labels.
Corresponds to the JSON property labels
894 895 896 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 894 def labels @labels end |
#name ⇒ String
Required. The resource name of the config. Must be in the format of, projects/
project/locations/location/googleChannelConfig. In API responses, the
config name always includes the projectID, regardless of whether the projectID
or projectNumber was provided.
Corresponds to the JSON property name
902 903 904 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 902 def name @name end |
#update_time ⇒ String
Output only. The last-modified time.
Corresponds to the JSON property updateTime
907 908 909 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 907 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
914 915 916 917 918 919 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 914 def update!(**args) @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |