Class: Google::Apis::EventarcV1::GoogleChannelConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb

Overview

A GoogleChannelConfig is a resource that stores the custom settings respected by Eventarc first-party triggers in the matching region. Once configured, first-party event data will be protected using the specified custom managed encryption key instead of Google-managed encryption keys.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChannelConfig

Returns a new instance of GoogleChannelConfig.



908
909
910
# File 'lib/google/apis/eventarc_v1/classes.rb', line 908

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#crypto_key_nameString

Optional. Resource name of a KMS crypto key (managed by the user) used to encrypt/decrypt their event data. It must match the pattern projects/*/ locations/*/keyRings/*/cryptoKeys/*. Corresponds to the JSON property cryptoKeyName

Returns:

  • (String)


888
889
890
# File 'lib/google/apis/eventarc_v1/classes.rb', line 888

def crypto_key_name
  @crypto_key_name
end

#labelsHash<String,String>

Optional. Resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


893
894
895
# File 'lib/google/apis/eventarc_v1/classes.rb', line 893

def labels
  @labels
end

#nameString

Required. The resource name of the config. Must be in the format of, projects/ project/locations/location/googleChannelConfig. In API responses, the config name always includes the projectID, regardless of whether the projectID or projectNumber was provided. Corresponds to the JSON property name

Returns:

  • (String)


901
902
903
# File 'lib/google/apis/eventarc_v1/classes.rb', line 901

def name
  @name
end

#update_timeString

Output only. The last-modified time. Corresponds to the JSON property updateTime

Returns:

  • (String)


906
907
908
# File 'lib/google/apis/eventarc_v1/classes.rb', line 906

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



913
914
915
916
917
918
# File 'lib/google/apis/eventarc_v1/classes.rb', line 913

def update!(**args)
  @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end