Class: Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineDestination

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb

Overview

Represents a target of an invocation over HTTP.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudEventarcV1PipelineDestination

Returns a new instance of GoogleCloudEventarcV1PipelineDestination.



968
969
970
# File 'lib/google/apis/eventarc_v1/classes.rb', line 968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_configGoogle::Apis::EventarcV1::GoogleCloudEventarcV1PipelineDestinationAuthenticationConfig

Represents a config used to authenticate message requests. Corresponds to the JSON property authenticationConfig



928
929
930
# File 'lib/google/apis/eventarc_v1/classes.rb', line 928

def authentication_config
  @authentication_config
end

#http_endpointGoogle::Apis::EventarcV1::GoogleCloudEventarcV1PipelineDestinationHttpEndpoint

Represents a HTTP endpoint destination. Corresponds to the JSON property httpEndpoint



933
934
935
# File 'lib/google/apis/eventarc_v1/classes.rb', line 933

def http_endpoint
  @http_endpoint
end

#message_busString

Optional. The resource name of the Message Bus to which events should be published. The Message Bus resource should exist in the same project as the Pipeline. Format: projects/project/locations/location/messageBuses/ message_bus` Corresponds to the JSON propertymessageBus`

Returns:

  • (String)


941
942
943
# File 'lib/google/apis/eventarc_v1/classes.rb', line 941

def message_bus
  @message_bus
end

#network_configGoogle::Apis::EventarcV1::GoogleCloudEventarcV1PipelineDestinationNetworkConfig

Represents a network config to be used for destination resolution and connectivity. Corresponds to the JSON property networkConfig



947
948
949
# File 'lib/google/apis/eventarc_v1/classes.rb', line 947

def network_config
  @network_config
end

#output_payload_formatGoogle::Apis::EventarcV1::GoogleCloudEventarcV1PipelineMessagePayloadFormat

Represents the format of message data. Corresponds to the JSON property outputPayloadFormat



952
953
954
# File 'lib/google/apis/eventarc_v1/classes.rb', line 952

def output_payload_format
  @output_payload_format
end

#topicString

Optional. The resource name of the Pub/Sub topic to which events should be published. Format: projects/project/locations/location/topics/topic` Corresponds to the JSON propertytopic`

Returns:

  • (String)


958
959
960
# File 'lib/google/apis/eventarc_v1/classes.rb', line 958

def topic
  @topic
end

#workflowString

Optional. The resource name of the Workflow whose Executions are triggered by the events. The Workflow resource should be deployed in the same project as the Pipeline. Format: projects/project/locations/location/workflows/ workflow` Corresponds to the JSON propertyworkflow`

Returns:

  • (String)


966
967
968
# File 'lib/google/apis/eventarc_v1/classes.rb', line 966

def workflow
  @workflow
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



973
974
975
976
977
978
979
980
981
# File 'lib/google/apis/eventarc_v1/classes.rb', line 973

def update!(**args)
  @authentication_config = args[:authentication_config] if args.key?(:authentication_config)
  @http_endpoint = args[:http_endpoint] if args.key?(:http_endpoint)
  @message_bus = args[:message_bus] if args.key?(:message_bus)
  @network_config = args[:network_config] if args.key?(:network_config)
  @output_payload_format = args[:output_payload_format] if args.key?(:output_payload_format)
  @topic = args[:topic] if args.key?(:topic)
  @workflow = args[:workflow] if args.key?(:workflow)
end