Class: Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineDestinationAuthenticationConfig
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineDestinationAuthenticationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
Represents a config used to authenticate message requests.
Instance Attribute Summary collapse
-
#google_oidc ⇒ Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOidcToken
Represents a config used to authenticate with a Google OIDC token using a Google Cloud service account.
-
#oauth_token ⇒ Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOAuthToken
Contains information needed for generating an OAuth token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudEventarcV1PipelineDestinationAuthenticationConfig
constructor
A new instance of GoogleCloudEventarcV1PipelineDestinationAuthenticationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudEventarcV1PipelineDestinationAuthenticationConfig
Returns a new instance of GoogleCloudEventarcV1PipelineDestinationAuthenticationConfig.
1003 1004 1005 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1003 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_oidc ⇒ Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOidcToken
Represents a config used to authenticate with a Google OIDC token using a
Google Cloud service account. Use this authentication method to invoke your
Cloud Run and Cloud Functions destinations or HTTP endpoints that support
Google OIDC.
Corresponds to the JSON property googleOidc
994 995 996 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 994 def google_oidc @google_oidc end |
#oauth_token ⇒ Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOAuthToken
Contains information needed for generating an OAuth token. This type of authorization should
generally only be used when calling Google APIs hosted on *.googleapis.com.
Corresponds to the JSON property oauthToken
1001 1002 1003 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1001 def oauth_token @oauth_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1008 1009 1010 1011 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1008 def update!(**args) @google_oidc = args[:google_oidc] if args.key?(:google_oidc) @oauth_token = args[:oauth_token] if args.key?(:oauth_token) end |