Class: Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOidcToken
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOidcToken
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
Represents a config used to authenticate with a Google OIDC token using a Google Cloud service account. Use this authentication method to invoke your Cloud Run and Cloud Functions destinations or HTTP endpoints that support Google OIDC.
Instance Attribute Summary collapse
-
#audience ⇒ String
Optional.
-
#service_account ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOidcToken
constructor
A new instance of GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOidcToken.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOidcToken
Returns a new instance of GoogleCloudEventarcV1PipelineDestinationAuthenticationConfigOidcToken.
1072 1073 1074 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1072 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audience ⇒ String
Optional. Audience to be used to generate the OIDC Token. The audience claim
identifies the recipient that the JWT is intended for. If unspecified, the
destination URI will be used.
Corresponds to the JSON property audience
1060 1061 1062 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1060 def audience @audience end |
#service_account ⇒ String
Required. Service account email used to generate the OIDC Token. The principal
who calls this API must have iam.serviceAccounts.actAs permission in the
service account. See https://cloud.google.com/iam/docs/understanding-service-
accounts for more information. Eventarc service agents must have roles/roles/
iam.serviceAccountTokenCreator role to allow the Pipeline to create OpenID
tokens for authenticated requests.
Corresponds to the JSON property serviceAccount
1070 1071 1072 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1070 def service_account @service_account end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1077 1078 1079 1080 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1077 def update!(**args) @audience = args[:audience] if args.key?(:audience) @service_account = args[:service_account] if args.key?(:service_account) end |