Class: Google::Apis::EventarcV1::ListGoogleApiSourcesResponse
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::ListGoogleApiSourcesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
The response message for the ListGoogleApiSources method.
Instance Attribute Summary collapse
-
#google_api_sources ⇒ Array<Google::Apis::EventarcV1::GoogleApiSource>
The requested GoogleApiSources, up to the number specified in
page_size. -
#next_page_token ⇒ String
A page token that can be sent to
ListMessageBusEnrollmentsto request the next page. -
#unreachable ⇒ Array<String>
Unreachable resources, if any.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListGoogleApiSourcesResponse
constructor
A new instance of ListGoogleApiSourcesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListGoogleApiSourcesResponse
Returns a new instance of ListGoogleApiSourcesResponse.
1711 1712 1713 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1711 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_api_sources ⇒ Array<Google::Apis::EventarcV1::GoogleApiSource>
The requested GoogleApiSources, up to the number specified in page_size.
Corresponds to the JSON property googleApiSources
1698 1699 1700 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1698 def google_api_sources @google_api_sources end |
#next_page_token ⇒ String
A page token that can be sent to ListMessageBusEnrollments to request the
next page. If this is empty, then there are no more pages.
Corresponds to the JSON property nextPageToken
1704 1705 1706 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1704 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unreachable resources, if any.
Corresponds to the JSON property unreachable
1709 1710 1711 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1709 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1716 1717 1718 1719 1720 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1716 def update!(**args) @google_api_sources = args[:google_api_sources] if args.key?(:google_api_sources) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |