Class: Google::Apis::EventarcV1::ListGoogleApiSourcesResponse
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::ListGoogleApiSourcesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
The response message for the ListGoogleApiSources method.
Instance Attribute Summary collapse
-
#google_api_sources ⇒ Array<Google::Apis::EventarcV1::GoogleApiSource>
The requested GoogleApiSources, up to the number specified in
page_size. -
#next_page_token ⇒ String
A page token that can be sent to
ListMessageBusEnrollmentsto request the next page. -
#unreachable ⇒ Array<String>
Unreachable resources, if any.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListGoogleApiSourcesResponse
constructor
A new instance of ListGoogleApiSourcesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListGoogleApiSourcesResponse
Returns a new instance of ListGoogleApiSourcesResponse.
1710 1711 1712 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1710 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_api_sources ⇒ Array<Google::Apis::EventarcV1::GoogleApiSource>
The requested GoogleApiSources, up to the number specified in page_size.
Corresponds to the JSON property googleApiSources
1697 1698 1699 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1697 def google_api_sources @google_api_sources end |
#next_page_token ⇒ String
A page token that can be sent to ListMessageBusEnrollments to request the
next page. If this is empty, then there are no more pages.
Corresponds to the JSON property nextPageToken
1703 1704 1705 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1703 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unreachable resources, if any.
Corresponds to the JSON property unreachable
1708 1709 1710 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1708 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1715 1716 1717 1718 1719 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1715 def update!(**args) @google_api_sources = args[:google_api_sources] if args.key?(:google_api_sources) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |