Class: Google::Apis::EventarcV1::ListMessageBusEnrollmentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::ListMessageBusEnrollmentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
The response message for the ListMessageBusEnrollments method.`
Instance Attribute Summary collapse
-
#enrollments ⇒ Array<String>
The requested enrollments, up to the number specified in
page_size. -
#next_page_token ⇒ String
A page token that can be sent to
ListMessageBusEnrollmentsto request the next page. -
#unreachable ⇒ Array<String>
Unreachable resources, if any.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMessageBusEnrollmentsResponse
constructor
A new instance of ListMessageBusEnrollmentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMessageBusEnrollmentsResponse
Returns a new instance of ListMessageBusEnrollmentsResponse.
1767 1768 1769 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1767 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enrollments ⇒ Array<String>
The requested enrollments, up to the number specified in page_size.
Corresponds to the JSON property enrollments
1754 1755 1756 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1754 def enrollments @enrollments end |
#next_page_token ⇒ String
A page token that can be sent to ListMessageBusEnrollments to request the
next page. If this is empty, then there are no more pages.
Corresponds to the JSON property nextPageToken
1760 1761 1762 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1760 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unreachable resources, if any.
Corresponds to the JSON property unreachable
1765 1766 1767 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1765 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1772 1773 1774 1775 1776 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1772 def update!(**args) @enrollments = args[:enrollments] if args.key?(:enrollments) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |