Class: Google::Apis::EventarcV1::ListMessageBusesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb

Overview

The response message for the ListMessageBuses method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMessageBusesResponse

Returns a new instance of ListMessageBusesResponse.



1799
1800
1801
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1799

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#message_busesArray<Google::Apis::EventarcV1::MessageBus>

The requested message buses, up to the number specified in page_size. Corresponds to the JSON property messageBuses



1786
1787
1788
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1786

def message_buses
  @message_buses
end

#next_page_tokenString

A page token that can be sent to ListMessageBuses to request the next page. If this is empty, then there are no more pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1792
1793
1794
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1792

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unreachable resources, if any. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1797
1798
1799
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1797

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1804
1805
1806
1807
1808
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1804

def update!(**args)
  @message_buses = args[:message_buses] if args.key?(:message_buses)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end