Class: Google::Apis::EventarcV1::ListPipelinesResponse
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::ListPipelinesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
The response message for the ListPipelines method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A page token that can be sent to
ListPipelinesto request the next page. -
#pipelines ⇒ Array<Google::Apis::EventarcV1::Pipeline>
The requested pipelines, up to the number specified in
page_size. -
#unreachable ⇒ Array<String>
Unreachable resources, if any.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPipelinesResponse
constructor
A new instance of ListPipelinesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPipelinesResponse
Returns a new instance of ListPipelinesResponse.
1832 1833 1834 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1832 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A page token that can be sent to ListPipelines to request the next page. If
this is empty, then there are no more pages.
Corresponds to the JSON property nextPageToken
1820 1821 1822 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1820 def next_page_token @next_page_token end |
#pipelines ⇒ Array<Google::Apis::EventarcV1::Pipeline>
The requested pipelines, up to the number specified in page_size.
Corresponds to the JSON property pipelines
1825 1826 1827 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1825 def pipelines @pipelines end |
#unreachable ⇒ Array<String>
Unreachable resources, if any.
Corresponds to the JSON property unreachable
1830 1831 1832 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1830 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1837 1838 1839 1840 1841 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1837 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @pipelines = args[:pipelines] if args.key?(:pipelines) @unreachable = args[:unreachable] if args.key?(:unreachable) end |