Class: Google::Apis::EventarcV1::ListProvidersResponse
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::ListProvidersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
The response message for the ListProviders method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A page token that can be sent to
ListProvidersto request the next page. -
#providers ⇒ Array<Google::Apis::EventarcV1::Provider>
The requested providers, up to the number specified in
page_size. -
#unreachable ⇒ Array<String>
Unreachable resources, if any.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListProvidersResponse
constructor
A new instance of ListProvidersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListProvidersResponse
Returns a new instance of ListProvidersResponse.
1863 1864 1865 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1863 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A page token that can be sent to ListProviders to request the next page. If
this is empty, then there are no more pages.
Corresponds to the JSON property nextPageToken
1851 1852 1853 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1851 def next_page_token @next_page_token end |
#providers ⇒ Array<Google::Apis::EventarcV1::Provider>
The requested providers, up to the number specified in page_size.
Corresponds to the JSON property providers
1856 1857 1858 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1856 def providers @providers end |
#unreachable ⇒ Array<String>
Unreachable resources, if any.
Corresponds to the JSON property unreachable
1861 1862 1863 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1861 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1868 1869 1870 1871 1872 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1868 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @providers = args[:providers] if args.key?(:providers) @unreachable = args[:unreachable] if args.key?(:unreachable) end |