Class: Google::Apis::EventarcV1::ListTriggersResponse
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::ListTriggersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
The response message for the ListTriggers method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A page token that can be sent to
ListTriggersto request the next page. -
#triggers ⇒ Array<Google::Apis::EventarcV1::Trigger>
The requested triggers, up to the number specified in
page_size. -
#unreachable ⇒ Array<String>
Unreachable resources, if any.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListTriggersResponse
constructor
A new instance of ListTriggersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListTriggersResponse
Returns a new instance of ListTriggersResponse.
1895 1896 1897 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1895 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A page token that can be sent to ListTriggers to request the next page. If
this is empty, then there are no more pages.
Corresponds to the JSON property nextPageToken
1883 1884 1885 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1883 def next_page_token @next_page_token end |
#triggers ⇒ Array<Google::Apis::EventarcV1::Trigger>
The requested triggers, up to the number specified in page_size.
Corresponds to the JSON property triggers
1888 1889 1890 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1888 def triggers @triggers end |
#unreachable ⇒ Array<String>
Unreachable resources, if any.
Corresponds to the JSON property unreachable
1893 1894 1895 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1893 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1900 1901 1902 1903 1904 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1900 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @triggers = args[:triggers] if args.key?(:triggers) @unreachable = args[:unreachable] if args.key?(:unreachable) end |