Class: Google::Apis::EventarcV1::MessageBus
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::MessageBus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
MessageBus for the messages flowing through the system. The admin has visibility and control over the messages being published and consumed and can restrict publishers and subscribers to only a subset of data available in the system by defining authorization policies.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#crypto_key_name ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#logging_config ⇒ Google::Apis::EventarcV1::LoggingConfig
The configuration for Platform Telemetry logging for Eventarc Advanced resources.
-
#name ⇒ String
Identifier.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MessageBus
constructor
A new instance of MessageBus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MessageBus
Returns a new instance of MessageBus.
2041 2042 2043 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2041 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Resource annotations.
Corresponds to the JSON property annotations
1987 1988 1989 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1987 def annotations @annotations end |
#create_time ⇒ String
Output only. The creation time.
Corresponds to the JSON property createTime
1992 1993 1994 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1992 def create_time @create_time end |
#crypto_key_name ⇒ String
Optional. Resource name of a KMS crypto key (managed by the user) used to
encrypt/decrypt their event data. It must match the pattern projects/*/
locations/*/keyRings/*/cryptoKeys/*.
Corresponds to the JSON property cryptoKeyName
1999 2000 2001 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1999 def crypto_key_name @crypto_key_name end |
#display_name ⇒ String
Optional. Resource display name.
Corresponds to the JSON property displayName
2004 2005 2006 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2004 def display_name @display_name end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and might be sent only on update and delete requests to ensure
that the client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
2011 2012 2013 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2011 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Resource labels.
Corresponds to the JSON property labels
2016 2017 2018 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2016 def labels @labels end |
#logging_config ⇒ Google::Apis::EventarcV1::LoggingConfig
The configuration for Platform Telemetry logging for Eventarc Advanced
resources.
Corresponds to the JSON property loggingConfig
2022 2023 2024 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2022 def logging_config @logging_config end |
#name ⇒ String
Identifier. Resource name of the form projects/project/locations/location/
messageBuses/message_bus
Corresponds to the JSON property name
2028 2029 2030 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2028 def name @name end |
#uid ⇒ String
Output only. Server assigned unique identifier for the channel. The value is a
UUID4 string and guaranteed to remain unchanged until the resource is deleted.
Corresponds to the JSON property uid
2034 2035 2036 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2034 def uid @uid end |
#update_time ⇒ String
Output only. The last-modified time.
Corresponds to the JSON property updateTime
2039 2040 2041 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2039 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2046 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @logging_config = args[:logging_config] if args.key?(:logging_config) @name = args[:name] if args.key?(:name) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |