Class: Google::Apis::EventarcV1::MessageBus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb

Overview

MessageBus for the messages flowing through the system. The admin has visibility and control over the messages being published and consumed and can restrict publishers and subscribers to only a subset of data available in the system by defining authorization policies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MessageBus

Returns a new instance of MessageBus.



2040
2041
2042
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2040

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Resource annotations. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1986
1987
1988
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1986

def annotations
  @annotations
end

#create_timeString

Output only. The creation time. Corresponds to the JSON property createTime

Returns:

  • (String)


1991
1992
1993
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1991

def create_time
  @create_time
end

#crypto_key_nameString

Optional. Resource name of a KMS crypto key (managed by the user) used to encrypt/decrypt their event data. It must match the pattern projects/*/ locations/*/keyRings/*/cryptoKeys/*. Corresponds to the JSON property cryptoKeyName

Returns:

  • (String)


1998
1999
2000
# File 'lib/google/apis/eventarc_v1/classes.rb', line 1998

def crypto_key_name
  @crypto_key_name
end

#display_nameString

Optional. Resource display name. Corresponds to the JSON property displayName

Returns:

  • (String)


2003
2004
2005
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2003

def display_name
  @display_name
end

#etagString

Output only. This checksum is computed by the server based on the value of other fields, and might be sent only on update and delete requests to ensure that the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


2010
2011
2012
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2010

def etag
  @etag
end

#labelsHash<String,String>

Optional. Resource labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2015
2016
2017
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2015

def labels
  @labels
end

#logging_configGoogle::Apis::EventarcV1::LoggingConfig

The configuration for Platform Telemetry logging for Eventarc Advanced resources. Corresponds to the JSON property loggingConfig



2021
2022
2023
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2021

def logging_config
  @logging_config
end

#nameString

Identifier. Resource name of the form projects/project/locations/location/ messageBuses/message_bus Corresponds to the JSON property name

Returns:

  • (String)


2027
2028
2029
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2027

def name
  @name
end

#uidString

Output only. Server assigned unique identifier for the channel. The value is a UUID4 string and guaranteed to remain unchanged until the resource is deleted. Corresponds to the JSON property uid

Returns:

  • (String)


2033
2034
2035
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2033

def uid
  @uid
end

#update_timeString

Output only. The last-modified time. Corresponds to the JSON property updateTime

Returns:

  • (String)


2038
2039
2040
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2038

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2045

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @create_time = args[:create_time] if args.key?(:create_time)
  @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @logging_config = args[:logging_config] if args.key?(:logging_config)
  @name = args[:name] if args.key?(:name)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end