Class: Google::Apis::EventarcV1::Pipeline
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::Pipeline
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
A representation of the Pipeline resource.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#create_time ⇒ String
Output only.
-
#crypto_key_name ⇒ String
Optional.
-
#destinations ⇒ Array<Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineDestination>
Required.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#input_payload_format ⇒ Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineMessagePayloadFormat
Represents the format of message data.
-
#labels ⇒ Hash<String,String>
Optional.
-
#logging_config ⇒ Google::Apis::EventarcV1::LoggingConfig
The configuration for Platform Telemetry logging for Eventarc Advanced resources.
-
#mediations ⇒ Array<Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineMediation>
Optional.
-
#name ⇒ String
Identifier.
-
#retry_policy ⇒ Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineRetryPolicy
The retry policy configuration for the Pipeline.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Pipeline
constructor
A new instance of Pipeline.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Pipeline
Returns a new instance of Pipeline.
2265 2266 2267 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2265 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. User-defined annotations. See https://google.aip.dev/128#annotations.
Corresponds to the JSON property annotations
2167 2168 2169 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2167 def annotations @annotations end |
#create_time ⇒ String
Output only. The creation time. A timestamp in RFC3339 UTC "Zulu" format, with
nanosecond resolution and up to nine fractional digits. Examples: "2014-10-
02T15:01:23Z" and "2014-10-02T15:01:23.045123456Z".
Corresponds to the JSON property createTime
2174 2175 2176 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2174 def create_time @create_time end |
#crypto_key_name ⇒ String
Optional. Resource name of a KMS crypto key (managed by the user) used to
encrypt/decrypt the event data. If not set, an internal Google-owned key will
be used to encrypt messages. It must match the pattern "projects/project/
locations/location/keyRings/keyring/cryptoKeys/key".
Corresponds to the JSON property cryptoKeyName
2182 2183 2184 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2182 def crypto_key_name @crypto_key_name end |
#destinations ⇒ Array<Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineDestination>
Required. List of destinations to which messages will be forwarded. Currently,
exactly one destination is supported per Pipeline.
Corresponds to the JSON property destinations
2188 2189 2190 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2188 def destinations @destinations end |
#display_name ⇒ String
Optional. Display name of resource.
Corresponds to the JSON property displayName
2193 2194 2195 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2193 def display_name @display_name end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and might be sent only on create requests to ensure that the
client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
2200 2201 2202 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2200 def etag @etag end |
#input_payload_format ⇒ Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineMessagePayloadFormat
Represents the format of message data.
Corresponds to the JSON property inputPayloadFormat
2205 2206 2207 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2205 def input_payload_format @input_payload_format end |
#labels ⇒ Hash<String,String>
Optional. User labels attached to the Pipeline that can be used to group
resources. An object containing a list of "key": value pairs. Example: "name"
: "wrench", "mass": "1.3kg", "count": "3".
Corresponds to the JSON property labels
2212 2213 2214 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2212 def labels @labels end |
#logging_config ⇒ Google::Apis::EventarcV1::LoggingConfig
The configuration for Platform Telemetry logging for Eventarc Advanced
resources.
Corresponds to the JSON property loggingConfig
2218 2219 2220 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2218 def logging_config @logging_config end |
#mediations ⇒ Array<Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineMediation>
Optional. List of mediation operations to be performed on the message.
Currently, only one Transformation operation is allowed in each Pipeline.
Corresponds to the JSON property mediations
2224 2225 2226 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2224 def mediations @mediations end |
#name ⇒ String
Identifier. The resource name of the Pipeline. Must be unique within the
location of the project and must be in projects/project/locations/location
/pipelines/pipeline`format.
Corresponds to the JSON propertyname`
2231 2232 2233 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2231 def name @name end |
#retry_policy ⇒ Google::Apis::EventarcV1::GoogleCloudEventarcV1PipelineRetryPolicy
The retry policy configuration for the Pipeline. The pipeline exponentially
backs off in case the destination is non responsive or returns a retryable
error code. The default semantics are as follows: The backoff starts with a 5
second delay and doubles the delay after each failed attempt (10 seconds, 20
seconds, 40 seconds, etc.). The delay is capped at 60 seconds by default.
Please note that if you set the min_retry_delay and max_retry_delay fields to
the same value this will make the duration between retries constant.
Corresponds to the JSON property retryPolicy
2242 2243 2244 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2242 def retry_policy @retry_policy end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Whether or not this Pipeline satisfies the requirements of
physical zone separation
Corresponds to the JSON property satisfiesPzs
2248 2249 2250 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2248 def satisfies_pzs @satisfies_pzs end |
#uid ⇒ String
Output only. Server-assigned unique identifier for the Pipeline. The value is
a UUID4 string and guaranteed to remain unchanged until the resource is
deleted.
Corresponds to the JSON property uid
2256 2257 2258 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2256 def uid @uid end |
#update_time ⇒ String
Output only. The last-modified time. A timestamp in RFC3339 UTC "Zulu" format,
with nanosecond resolution and up to nine fractional digits. Examples: "2014-
10-02T15:01:23Z" and "2014-10-02T15:01:23.045123456Z".
Corresponds to the JSON property updateTime
2263 2264 2265 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2263 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2270 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @create_time = args[:create_time] if args.key?(:create_time) @crypto_key_name = args[:crypto_key_name] if args.key?(:crypto_key_name) @destinations = args[:destinations] if args.key?(:destinations) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @input_payload_format = args[:input_payload_format] if args.key?(:input_payload_format) @labels = args[:labels] if args.key?(:labels) @logging_config = args[:logging_config] if args.key?(:logging_config) @mediations = args[:mediations] if args.key?(:mediations) @name = args[:name] if args.key?(:name) @retry_policy = args[:retry_policy] if args.key?(:retry_policy) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |