Class: Google::Apis::EventarcV1::ProjectSubscriptions
- Inherits:
-
Object
- Object
- Google::Apis::EventarcV1::ProjectSubscriptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb
Overview
Config to enable subscribing to all events from a list of projects.
Instance Attribute Summary collapse
-
#list ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProjectSubscriptions
constructor
A new instance of ProjectSubscriptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProjectSubscriptions
Returns a new instance of ProjectSubscriptions.
2395 2396 2397 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2395 def initialize(**args) update!(**args) end |
Instance Attribute Details
#list ⇒ Array<String>
Required. A list of projects to receive events from. All the projects must be
in the same org. The listed projects should have the format project/
identifier where identifier can be either the project id for project number.
A single list may contain both formats. At most 100 projects can be listed.
Corresponds to the JSON property list
2393 2394 2395 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2393 def list @list end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2400 2401 2402 |
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2400 def update!(**args) @list = args[:list] if args.key?(:list) end |