Class: Google::Apis::EventarcV1::Trigger

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/eventarc_v1/classes.rb,
lib/google/apis/eventarc_v1/representations.rb,
lib/google/apis/eventarc_v1/representations.rb

Overview

A representation of the trigger resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Trigger

Returns a new instance of Trigger.



2726
2727
2728
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2726

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channelString

Optional. The name of the channel associated with the trigger in projects/ project/locations/location/channels/channel`format. You must provide a channel to receive events from Eventarc SaaS partners. Corresponds to the JSON propertychannel`

Returns:

  • (String)


2636
2637
2638
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2636

def channel
  @channel
end

#conditionsHash<String,Google::Apis::EventarcV1::StateCondition>

Output only. The reason(s) why a trigger is in FAILED state. Corresponds to the JSON property conditions



2641
2642
2643
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2641

def conditions
  @conditions
end

#create_timeString

Output only. The creation time. Corresponds to the JSON property createTime

Returns:

  • (String)


2646
2647
2648
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2646

def create_time
  @create_time
end

#destinationGoogle::Apis::EventarcV1::Destination

Represents a target of an invocation over HTTP. Corresponds to the JSON property destination



2651
2652
2653
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2651

def destination
  @destination
end

#etagString

Output only. This checksum is computed by the server based on the value of other fields, and might be sent only on create requests to ensure that the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


2658
2659
2660
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2658

def etag
  @etag
end

#event_data_content_typeString

Optional. EventDataContentType specifies the type of payload in MIME format that is expected from the CloudEvent data field. This is set to application/ json if the value is not defined. Corresponds to the JSON property eventDataContentType

Returns:

  • (String)


2665
2666
2667
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2665

def event_data_content_type
  @event_data_content_type
end

#event_filtersArray<Google::Apis::EventarcV1::EventFilter>

Required. Unordered list. The list of filters that applies to event attributes. Only events that match all the provided filters are sent to the destination. Corresponds to the JSON property eventFilters



2671
2672
2673
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2671

def event_filters
  @event_filters
end

#labelsHash<String,String>

Optional. User labels attached to the triggers that can be used to group resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2677
2678
2679
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2677

def labels
  @labels
end

#nameString

Required. The resource name of the trigger. Must be unique within the location of the project and must be in projects/project/locations/location/ triggers/trigger`format. Corresponds to the JSON propertyname`

Returns:

  • (String)


2684
2685
2686
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2684

def name
  @name
end

#retry_policyGoogle::Apis::EventarcV1::RetryPolicy

The retry policy configuration for the Trigger. Can only be set with Cloud Run destinations. Corresponds to the JSON property retryPolicy



2690
2691
2692
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2690

def retry_policy
  @retry_policy
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Whether or not this Trigger satisfies the requirements of physical zone separation Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


2696
2697
2698
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2696

def satisfies_pzs
  @satisfies_pzs
end

#service_accountString

Optional. The IAM service account email associated with the trigger. The service account represents the identity of the trigger. The iam. serviceAccounts.actAs permission must be granted on the service account to allow a principal to impersonate the service account. For more information, see the Roles and permissions page specific to the trigger destination. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


2707
2708
2709
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2707

def 
  @service_account
end

#transportGoogle::Apis::EventarcV1::Transport

Represents the transport intermediaries created for the trigger to deliver events. Corresponds to the JSON property transport



2713
2714
2715
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2713

def transport
  @transport
end

#uidString

Output only. Server-assigned unique identifier for the trigger. The value is a UUID4 string and guaranteed to remain unchanged until the resource is deleted. Corresponds to the JSON property uid

Returns:

  • (String)


2719
2720
2721
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2719

def uid
  @uid
end

#update_timeString

Output only. The last-modified time. Corresponds to the JSON property updateTime

Returns:

  • (String)


2724
2725
2726
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2724

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
2744
2745
2746
2747
# File 'lib/google/apis/eventarc_v1/classes.rb', line 2731

def update!(**args)
  @channel = args[:channel] if args.key?(:channel)
  @conditions = args[:conditions] if args.key?(:conditions)
  @create_time = args[:create_time] if args.key?(:create_time)
  @destination = args[:destination] if args.key?(:destination)
  @etag = args[:etag] if args.key?(:etag)
  @event_data_content_type = args[:event_data_content_type] if args.key?(:event_data_content_type)
  @event_filters = args[:event_filters] if args.key?(:event_filters)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @retry_policy = args[:retry_policy] if args.key?(:retry_policy)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @service_account = args[:service_account] if args.key?(:service_account)
  @transport = args[:transport] if args.key?(:transport)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end